@@ -2,6 +2,27 @@
 #' @export
 haven::as_factor
 
+#' @export
+as_factor.numeric <- function(x, ...) {
+  if (has_labels(x)) {
+    class(x) = c("haven_labelled", class(x))
+    haven::as_factor(x, ...)
+  } else {
+    haven::as_factor(x, ...)
+  }
+}
+
+#' @export
+as_factor.character <- function(x, ...) {
+  if (has_labels(x)) {
+    class(x) = c("haven_labelled", class(x))
+    haven::as_factor(x, ...)
+  } else {
+    haven::as_factor(x, ...)
+  }
+}
+
+
 #' @importFrom haven zap_label
 #' @export
 haven::zap_label
@@ -173,9 +194,9 @@ data_description_default <- function(data) {
 #'
 list_to_dict <- function(named_list) {
   dplyr::left_join(
-  tibble::data_frame(variable = names(named_list)),
+  tibble::tibble(variable = names(named_list)),
   tidyr::gather(
-    tibble::as_data_frame(
+    tibble::as_tibble(
       purrr::compact(named_list)),
     "variable", "label"), by = "variable")
 }
